@@ -5,6 +5,7 @@ import tempfile
 import tarfile
 import shutil
 import subprocess
+import argparse
 from ConfigParser import ConfigParser
 
 from distutils2.index.simple import Crawler
@@ -31,7 +32,7 @@ def get_last_release(project_name):
     return last_release.download()
 
 
-def _d1_sdist2rpm():
+def _d1_sdist2rpm(dist_dir):
     # grab the name and create a normalized one
     popen = subprocess.Popen('%s setup.py --name' % sys.executable,
                                 stdout=subprocess.PIPE, shell=True)
@@ -44,7 +45,10 @@ def _d1_sdist2rpm():
         name = 'python%d%d-%s' % (major, minor, name)
 
     # run the bdist_rpm2 command
-    cmd = '--command-packages=pypi2rpm.command bdist_rpm2 --fix-python'
+    cmd = ('--command-packages=pypi2rpm.command bdist_rpm2 --fix-python '
+           '--binary-only')
+    if dist_dir is not None:
+        cmd += ' --dist-dir=%s' % dist_dir
     res = subprocess.call('%s setup.py %s --name=%s' % \
             (sys.executable, cmd, name), shell=True)
     if res != 0:
@@ -52,7 +56,7 @@ def _d1_sdist2rpm():
         sys.exit(0)
 
 
-def _d2_sdist2rpm():
+def _d2_sdist2rpm(dist_dir):
     setup_cfg = ConfigParser()
     setup_cfg.read('setup.cfg')
     name = setup_cfg.get('metadata', 'name')
@@ -60,12 +64,14 @@ def _d2_sdist2rpm():
     if not name.startswith('python-'):
         name = 'python-%s' % name
 
+    cmd = '-m distutils2.run bdist_rpm2 --fix-python --binary-only'
+    if dist_dir is not None:
+        cmd += ' --dist-dir=%s' % dist_dir
     # run the bdist_rpm2 command
-    os.system('%s -m distutils2.run bdist_rpm2 --fix-python --name=%s' % \
-            (sys.executable, name))
+    os.system('%s %s --name=%s' % (sys.executable, cmd, name))
 
 
-def sdist2rpm(sdist):
+def sdist2rpm(sdist, dist_dir=None):
     """Creates a RPM distro out of a Python project."""
     old_dir = os.getcwd()
 
@@ -81,14 +87,16 @@ def sdist2rpm(sdist):
     os.chdir(sdist)
     try:
         if not _is_d2():
-            _d1_sdist2rpm()
+            _d1_sdist2rpm(dist_dir)
         else:
-            _d2_sdist2rpm()
+            _d2_sdist2rpm(dist_dir)
 
-        for file_ in os.listdir('dist'):
+        if dist_dir is None:
+            dist_dir = 'dist'
+        for file_ in os.listdir(dist_dir):
             if file_.endswith('.noarch.rpm'):
                 target = os.path.join(old_dir, file_)
-                shutil.copyfile(os.path.join('dist', file_), target)
+                shutil.copyfile(os.path.join(dist_dir, file_), target)
                 return target
     finally:
         os.chdir(old_dir)
@@ -96,8 +104,8 @@ def sdist2rpm(sdist):
             shutil.rmtree(tempdir)
 
 
-def main(project):
-    res = sdist2rpm(get_last_release(project))
+def main(project, dist_dir):
+    res = sdist2rpm(get_last_release(project), dist_dir)
     if res is None:
         print 'Failed.'
         return 1
@@ -105,8 +113,11 @@ def main(project):
     return 0
 
 if __name__ == '__main__':
-    if len(sys.argv) != 2:
-        print 'Usage: pypi2rpm [project name at pypi or path]'
-        sys.exit(1)
 
-    sys.exit(main(sys.argv[1]))
+    parser = argparse.ArgumentParser()
+    parser.add_argument('--dist-dir', type=str, default=None,
+                        help='target directory for RPM files')
+
+    parser.add_argument('project', help='project name at PyPI or path')
+    args = parser.parse_args()
+    sys.exit(main(args.project, args.dist_dir))
